<?php
/**
 * Ayyash Starter Content.
 *
 * @package Ayyash
 * @author ThemeOO
 * @version 1.0.0
 * @since Ayyash 1.0.5
 */

if ( ! defined( 'ABSPATH' ) ) {
	header( 'Status: 403 Forbidden' );
	header( 'HTTP/1.1 403 Forbidden' );
	die();
}

/**
 * Function to return the array of starter content for the theme.
 *
 * @since Ayyash 1.0.5
 *
 * @return array A filtered array of args for the starter_content.
 */
function themeoo_get_starter_content() {

	// phpcs:disable WordPressVIPMinimum.Security.Mustache.OutputNotation
	// Define and register starter content to showcase the theme on new sites.
	$starter_content = [
		// Specify the core-defined pages to create and add custom thumbnails to some of them.
		'posts'     => [
			'front' => [
				'post_type'    => 'page',
				'post_title'   => esc_html_x( 'Create your website with blocks', 'Theme starter content', 'ayyash' ),
				'post_content' => '
				<!-- wp:cover {"url":"' . esc_url( get_template_directory_uri() ) . '/assets/dist/images/starter-content/meeting-bg.jpg","id":170,"hasParallax":true,"dimRatio":85,"overlayColor":"black","minHeight":600,"minHeightUnit":"px","align":"full"} -->
				<div class="wp-block-cover alignfull has-background-dim-90 has-black-background-color has-background-dim has-parallax" style="background-image:url(' . esc_url( get_template_directory_uri() ) . '/assets/dist/images/starter-content/meeting-bg.jpg);min-height:600px"><div class="wp-block-cover__inner-container"><!-- wp:heading {"textAlign":"left","level":1,"textColor":"white"} -->
				<h1 class="has-text-align-left has-white-color has-text-color">' . __( 'We Provide Best Web Service', 'ayyash' ) . '</h1>
				<!-- /wp:heading -->

				<!-- wp:paragraph {"style":{"typography":{"lineHeight":"1.7"}}} -->
				<p style="line-height:1.7">' . __( 'If you are looking for an agency to help you create a remarkable presence online,<br>you have come to the right place. We can help you take your business to the next level.', 'ayyash' ) . '</p>
				<!-- /wp:paragraph -->

				<!-- wp:spacer {"height":22} -->
				<div style="height:22px" aria-hidden="true" class="wp-block-spacer"></div>
				<!-- /wp:spacer -->

				<!-- wp:buttons {"layout":{"type":"flex","justifyContent":"left","orientation":"horizontal"}} -->
				<div class="wp-block-buttons is-content-justification-left"><!-- wp:button {"textColor":"ast-global-color-3","style":{"color":{"background":"#2626f3"},"border":{"radius":"6px"},"typography":{"fontSize":"16px"}},"className":"is-style-fill"} -->
				<div class="wp-block-button has-custom-font-size is-style-fill" style="font-size:16px"><a class="wp-block-button__link has-ast-global-color-3-color has-text-color has-background" style="border-radius:6px;background-color:#2626f3" rel="#">' . __( 'Find out how!', 'ayyash' ) . '</a></div>
				<!-- /wp:button --></div>
				<!-- /wp:buttons --></div></div>
				<!-- /wp:cover -->

				<!-- wp:group {"align":"full","style":{"spacing":{"padding":{"top":"50px","bottom":"60px"}}}} -->
				<div class="wp-block-group alignfull" style="padding-top:50px;padding-bottom:60px"><!-- wp:heading {"textAlign":"center","style":{"typography":{"fontSize":"40px"}}} -->
				<h2 class="has-text-align-center" style="font-size:40px">' . __( 'Our Services', 'ayyash' ) . '</h2>
				<!-- /wp:heading -->

				<!-- wp:columns -->
				<div class="wp-block-columns"><!-- wp:column -->
				<div class="wp-block-column"><!-- wp:heading {"textAlign":"center","level":4,"style":{"typography":{"fontStyle":"normal","fontWeight":"700"}},"fontSize":"medium"} -->
				<h4 class="has-text-align-center has-medium-font-size"  style="font-style:normal;font-weight:700">' . __( 'Server Maintenance', 'ayyash' ) . '</h4>
				<!-- /wp:heading -->

				<!-- wp:paragraph {"align":"center"} -->
				<p class="has-text-align-center">' . __( 'We provides a broad range of server maintenance solutions for your websites or web applications. We can decrease your server costs and ensure a faster response time on a minimal budget with a 99% uptime Guarantee.', 'ayyash' ) . '</p>
				<!-- /wp:paragraph --></div>
				<!-- /wp:column -->

				<!-- wp:column -->
				<div class="wp-block-column"><!-- wp:heading {"textAlign":"center","level":4,"style":{"typography":{"fontStyle":"normal","fontWeight":"700"}},"fontSize":"medium"} -->
				<h4 class="has-text-align-center has-medium-font-size"  style="font-style:normal;font-weight:700">' . __( 'Web Development', 'ayyash' ) . '</h4>
				<!-- /wp:heading -->

				<!-- wp:paragraph {"align":"center"} -->
				<p class="has-text-align-center">' . __( 'Let us turn your imagination into reality. We are one of the top web development agencies in the world offering Dedicated Web Developers to help you with basic informational websites to complex web application development.', 'ayyash' ) . '</p>
				<!-- /wp:paragraph --></div>
				<!-- /wp:column -->

				<!-- wp:column {"verticalAlignment":"top"} -->
				<div class="wp-block-column is-vertically-aligned-top"><!-- wp:heading {"textAlign":"center","level":4,"style":{"typography":{"fontStyle":"normal","fontWeight":"700"}},"fontSize":"medium"} -->
				<h4 class="has-text-align-center has-medium-font-size"  style="font-style:normal;font-weight:700">' . __( 'e-Commerce Branding', 'ayyash' ) . '</h4>
				<!-- /wp:heading -->

				<!-- wp:paragraph {"align":"center"} -->
				<p class="has-text-align-center">' . __( 'E-Commerce branding &amp; promotion services that span brand identity, brand strategy, brand positioning and much more, all in the digital stratosphere. We creating all the branding you need for your online presence.', 'ayyash' ) . '</p>
				<!-- /wp:paragraph --></div>
				<!-- /wp:column --></div>
				<!-- /wp:columns --></div>
				<!-- /wp:group -->

				<!-- wp:group {"align":"full","style":{"spacing":{"padding":{"top":"80px","bottom":"60px"}}},"gradient":"blush-light-purple"} -->
				<div class="wp-block-group alignfull has-blush-light-purple-gradient-background has-background" style="padding-top:80px;padding-bottom:60px"><!-- wp:media-text {"mediaPosition":"right","mediaId":4232,"mediaLink":"http://ayyash.local/create-your-website-with-blocks/server/","mediaType":"image","mediaWidth":40,"mediaSizeSlug":"full","imageFill":true} -->
				<div class="wp-block-media-text alignwide has-media-on-the-right is-stacked-on-mobile is-image-fill" style="grid-template-columns:auto 40%"><figure class="wp-block-media-text__media" style="background-image:url(' . esc_url( get_template_directory_uri() ) . '/assets/dist/images/starter-content/server.png);background-position:50% 50%"><img src="' . esc_url( get_template_directory_uri() ) . '/assets/dist/images/starter-content/server.png" alt="" class="wp-image-4232 size-full"/></figure><div class="wp-block-media-text__content"><!-- wp:heading {"level":3,"style":{"typography":{"fontSize":"30px"}},"textColor":"black"} -->
				<h3 class="has-black-color has-text-color" style="font-size:30px"><strong>' . __( 'Dedicated web maintenance services', 'ayyash' ) . '</strong><br><span style="color:#2626f3" class="has-inline-color">' . __( 'for your business', 'ayyash' ) . '</span></h3>
				<!-- /wp:heading -->

				<!-- wp:paragraph {"style":{"typography":{"fontSize":"24px"}}} -->
				<p style="font-size:24px">' . __( 'Focus on your business &amp; Forget the complexity.', 'ayyash' ) . '<br/>' . __( 'Let us take your', 'ayyash' ) . '<strong><span style="color:#2626f3" class="has-inline-color">' . __( 'websites responsibility with extra care', 'ayyash' ) . '</span></strong></p>
				<!-- /wp:paragraph -->

				<!-- wp:buttons {"contentJustification":"left"} -->
				<div class="wp-block-buttons is-content-justification-left"><!-- wp:button {"width":75,"style":{"border":{"radius":5},"color":{"background":"#2626f3"},"typography":{"fontSize":"16px"}}} -->
				<div class="wp-block-button has-custom-width wp-block-button__width-75 has-custom-font-size" style="font-size:16px"><a class="wp-block-button__link has-background" style="border-radius:5px;background-color:#2626f3">' . __( 'Check all services', 'ayyash' ) . '</a></div>
				<!-- /wp:button -->
				</div>
				<!-- /wp:buttons -->
				</div>
				</div>
				<!-- /wp:media-text -->
				</div>
				<!-- /wp:group -->

				<!-- wp:group {"align":"full","backgroundColor":"ast-global-color-5"} -->
				<div class="wp-block-group alignfull has-ast-global-color-5-background-color has-background">
				<!-- wp:spacer {"height":70} -->
				<div style="height:70px" aria-hidden="true" class="wp-block-spacer"></div>
				<!-- /wp:spacer -->

				<!-- wp:heading {"textAlign":"center","style":{"typography":{"fontSize":"40px"}}} -->
				<h2 class="has-text-align-center" style="font-size:40px">' . __( 'Why Choose Us?', 'ayyash' ) . '</h2>
				<!-- /wp:heading -->

				<!-- wp:separator {"color":"cyan-bluish-gray","className":"is-style-wide"} -->
				<hr class="wp-block-separator has-text-color has-background has-cyan-bluish-gray-background-color has-cyan-bluish-gray-color is-style-wide"/>
				<!-- /wp:separator -->

				<!-- wp:paragraph -->
				<p><strong>' . __( 'We are the right term for your business. We have the expertise and knowledge to offer impartial advice and services at an honest price.', 'ayyash' ) . '</strong></p>
				<!-- /wp:paragraph -->

				<!-- wp:paragraph -->
				<p>' . __( 'With us you will feel heard. We listen to our client requirements and then select the right solution that fits. We care for your business as our own. We take a sincere interest in it and genuinely want to help your company reach its potential.', 'ayyash' ) . '</p>
				<!-- /wp:paragraph -->
				</div>
				<!-- /wp:group -->

				<!-- wp:spacer {"height":70} -->
				<div style="height:70px" aria-hidden="true" class="wp-block-spacer"></div>
				<!-- /wp:spacer -->

				<!-- wp:group {"align":"full","backgroundColor":"ast-global-color-5"} -->
				<div class="wp-block-group alignfull has-ast-global-color-5-background-color has-background"><!-- wp:heading {"textAlign":"center","style":{"typography":{"fontSize":"40px"}}} -->
				<h2 class="has-text-align-center" style="font-size:40px">' . __( 'Our Partners', 'ayyash' ) . '</h2>
				<!-- /wp:heading -->

				<!-- wp:gallery {"ids":[138,102,101,99],"columns":4,"imageCrop":false,"linkTo":"none","sizeSlug":"full","align":"center"} -->
				<figure class="wp-block-gallery aligncenter columns-4"><ul class="blocks-gallery-grid"><li class="blocks-gallery-item"><figure><img src="' . esc_url( get_template_directory_uri() ) . '/assets/dist/images/starter-content/absp_logo.png" alt="" data-id="138" data-full-url="' . esc_url( get_template_directory_uri() ) . '/assets/dist/images/starter-content/absp_logo.png" data-link="' . esc_url( get_template_directory_uri() ) . '/assets/dist/images/starter-content/absp_logo-1/" class="wp-image-138"/></figure></li><li class="blocks-gallery-item"><figure><img src="' . esc_url( get_template_directory_uri() ) . '/assets/dist/images/starter-content/theme00_logo.png" alt="" data-id="102" data-full-url="' . esc_url( get_template_directory_uri() ) . '/assets/dist/images/starter-content/theme00_logo.png" data-link="' . esc_url( get_template_directory_uri() ) . '/assets/dist/images/starter-content/theme00_logo/" class="wp-image-102"/></figure></li><li class="blocks-gallery-item"><figure><img src="' . esc_url( get_template_directory_uri() ) . '/assets/dist/images/starter-content//roxwp-logo.png" alt="" data-id="101" data-full-url="' . esc_url( get_template_directory_uri() ) . '/assets/dist/images/starter-content/roxwp-logo.png" data-link="' . esc_url( get_template_directory_uri() ) . '/assets/dist/images/starter-content/roxwp-logo/" class="wp-image-101"/></figure></li><li class="blocks-gallery-item"><figure><img src="' . esc_url( get_template_directory_uri() ) . '/assets/dist/images/starter-content/pixelaar-logo.png" alt="" data-id="99" data-full-url="' . esc_url( get_template_directory_uri() ) . '/assets/dist/images/starter-content/pixelaar-logo.png" data-link="' . esc_url( get_template_directory_uri() ) . '/assets/dist/images/starter-content//pixelaar-logo/" class="wp-image-99"/></figure></li></ul></figure>
				<!-- /wp:gallery --></div>
				<!-- /wp:group -->

				<!-- wp:group {"tagName":"section","align":"full","className":"cta-section"} -->
				<section class="wp-block-group alignfull cta-section"><!-- wp:columns {"className":"cta"} -->
				<div class="wp-block-columns cta"><!-- wp:column {"verticalAlignment":"center","width":"66.66%"} -->
				<div class="wp-block-column is-vertically-aligned-center" style="flex-basis:66.66%"><!-- wp:heading {"style":{"typography":{"fontSize":"40px"}}} -->
				<h2 style="font-size:40px">' . __( 'Need help ?', 'ayyash' ) . '</h2>
				<!-- /wp:heading -->

				<!-- wp:paragraph {"fontSize":"normal"} -->
				<p class="has-normal-font-size">' . __( 'Reach out with questions or feedback any time!', 'ayyash' ) . '</p>
				<!-- /wp:paragraph --></div>
				<!-- /wp:column -->

				<!-- wp:column {"verticalAlignment":"center","width":"33.33%"} -->
				<div class="wp-block-column is-vertically-aligned-center" style="flex-basis:33.33%"><!-- wp:buttons {"contentJustification":"right"} -->
				<div class="wp-block-buttons is-content-justification-right"><!-- wp:button {"width":100,"style":{"border":{"radius":4},"color":{"background":"#0f37d7"}},"fontSize":"medium"} -->
				<div class="wp-block-button has-custom-width wp-block-button__width-100 has-custom-font-size has-medium-font-size"><a class="wp-block-button__link has-background" style="border-radius:4px;background-color:#0f37d7">' . __( 'Contact Us', 'ayyash' ) . '</a></div>
				<!-- /wp:button --></div>
				<!-- /wp:buttons --></div>
				<!-- /wp:column --></div>
				<!-- /wp:columns --></section>
				<!-- /wp:group -->

				<!-- wp:html -->
				<style>
				.cta-section {
					background: rgba(7, 40, 171,  0.01) url(' . esc_url( get_template_directory_uri() ) . '/assets/dist/images/starter-content/cta-bg.png) fixed;
					background-size: auto;
					padding: 150px 55px;
				}
				</style>
				<!-- /wp:html -->
				',
			],
			'about',
			'contact',
			'blog',
		],
		// Default to a static front page and assign the front and posts pages.
		'options'   => [
			'show_on_front'  => 'page',
			'page_on_front'  => '{{front}}',
			'page_for_posts' => '{{blog}}',
		],
		// Set up nav menus for each of the two areas registered in the theme.
		'nav_menus' => [
			'primary' => [
				'name'  => esc_html__( 'Primary menu', 'ayyash' ),
				'items' => [
					'link_home',
					'page_about',
					'page_blog',
					'page_contact',
				],
			],
			'mobile'  => [
				'name'  => esc_html__( 'Mobile Menu', 'ayyash' ),
				'items' => [
					'link_home',
					'page_about',
					'page_blog',
					'page_contact',
					'link_facebook',
					'link_twitter',
					'link_instagram',
					'link_email',
				],
			],
		],
		'widgets'   => [
			'main-sidebar'         => [
				'search'          => [
					'search',
					[
						'title' => '',
					],
				],
				'recent-posts'    => [
					'recent-posts',
					[
						'title' => _x( 'Recent Posts', 'Theme starter content', 'ayyash' ),
					],
				],
				'recent-comments' => [
					'recent-comments',
					[
						'title' => _x( 'Recent Comments', 'Theme starter content', 'ayyash' ),
					],
				],
				'archives'        => [
					'archives',
					[
						'title' => _x( 'Archives', 'Theme starter content', 'ayyash' ),
					],
				],
				'categories'      => [
					'categories',
					[
						'title' => _x( 'Categories', 'Theme starter content', 'ayyash' ),
					],
				],
				'meta'            => [
					'meta',
					[
						'title' => _x( 'Meta', 'Theme starter content', 'ayyash' ),
					],
				],
			],
			'footer-top-widget'    => [
				'text_business_info' => [
					'title'  => _x( 'Find Us', 'Theme starter content', 'ayyash' ),
					'text'   => implode(
						'',
						[
							'<strong>' . _x( 'Address', 'Theme starter content', 'ayyash' ) . "</strong>\n",
							_x( '123 Main Street', 'Theme starter content', 'ayyash' ) . "\n" . _x( 'New York, NY 10001', 'Theme starter content', 'ayyash' ) . "\n\n",
							'<strong>' . _x( 'Hours', 'Theme starter content', 'ayyash' ) . "</strong>\n",
							_x( 'Monday&ndash;Friday: 9:00AM&ndash;5:00PM', 'Theme starter content', 'ayyash' ) . "\n" . _x( 'Saturday &amp; Sunday: 11:00AM&ndash;3:00PM', 'Theme starter content', 'ayyash' ),
						]
					),
					'filter' => true,
					'visual' => true,
				],
				'text_about'         => [
					'text',
					[
						'title'  => _x( 'About This Site', 'Theme starter content', 'ayyash' ),
						'text'   => _x( 'This may be a good place to introduce yourself and your site or include some credits.', 'Theme starter content', 'ayyash' ),
						'filter' => true,
						'visual' => true,
					],
				],
			],
			'footer-widget'        => [],
			'footer-bottom-widget' => [],
		],
	];

	// phpcs:enable

	/**
	 * Filters the array of starter content.
	 *
	 * @param array $starter_content Array of starter content.
	 */
	return apply_filters( 'themeoo_starter_content', $starter_content );
}

// End of file starter-content.php.
