<?php
/**
 * WC Hook Helpers.
 *
 * @package Ayyash
 * @author ThemeOO
 */

if ( ! defined( 'ABSPATH' ) ) {
	header( 'Status: 403 Forbidden' );
	header( 'HTTP/1.1 403 Forbidden' );
	die();
}

/**
----------------------------------------------------------------------
 * removing After and Before Main Content Hook So we can put our own layout
 * ----------------------------------------------------------------------*/
if ( ! function_exists( 'themeoo_woocommerce_init' ) ) :
	/**
	 * Add theme support and remove default action hooks so we can replace them with our own.
	 *
	 * @return void
	 */
	function themeoo_woocommerce_init() {
		add_theme_support( 'woocommerce' );
		/**
		----------------------------------------------------------------------
		 * Enable Product Zoom
		 * ----------------------------------------------------------------------*/
		if ( themeoo_get_mod( 'woocommerce_general_enable_product_zoom' ) ) {
			add_theme_support( 'wc-product-gallery-zoom' );
		} else {
			remove_theme_support( 'wc-product-gallery-zoom' );
		}

		/**
		----------------------------------------------------------------------
		 * Enable Product Lightbox
		 *----------------------------------------------------------------------*/
		if ( themeoo_get_mod( 'woocommerce_general_enable_product_lightbox' ) ) {
			add_theme_support( 'wc-product-gallery-lightbox' );
		} else {
			remove_theme_support( 'wc-product-gallery-lightbox' );
		}

		/**
		----------------------------------------------------------------------
		 * Enable Product Gallery Slider
		 * ----------------------------------------------------------------------*/
		if ( themeoo_get_mod( 'woocommerce_general_enable_product_gallery_slider' ) ) {
			add_theme_support( 'wc-product-gallery-slider' );
		} else {
			remove_theme_support( 'wc-product-gallery-slider' );
		}

		// remove default content wrapper.
		remove_action( 'woocommerce_before_main_content', 'woocommerce_output_content_wrapper' );
		remove_action( 'woocommerce_after_main_content', 'woocommerce_output_content_wrapper_end' );

	}
endif;

if ( ! function_exists( 'themeoo_loop_columns' ) ) {
	/**
	 * Override theme default specification for product # per row
	 *
	 * @param int $columns
	 *
	 * @return int
	 */
	function themeoo_loop_columns( $columns ) {
		$loop_columns = absint( themeoo_get_mod( 'woocommerce_shop_archive_column' ) );

		if ( $loop_columns ) {
			return $loop_columns;
		}

		return $columns;
	}
}

/**
----------------------------------------------------------------------
 * Writing After and Before Main Content Hook So we can put our own layout
 * ----------------------------------------------------------------------*/

if ( ! function_exists( 'themeoo_woocommerce_before_main_content' ) ) :
	/**
	 * Add markup layout before main WooCommerce content.
	 *
	 * @return void
	 */
	function themeoo_woocommerce_before_main_content() {
		$classes = apply_filters( 'themeoo_content_container_class', themeoo_get_mod( 'layout_global_content_layout' ) );
		$view    = themeoo_get_current_screen();
		?>
		<div  id="content">
			<?php themeoo_title_bar( $view ); ?>
			<div <?php themeoo_get_content_class(); ?>>
				<div class="<?php echo esc_attr( $classes ); ?>">
					<div class="row">
						<?php themeoo_try_sidebar( $view, 'left' ); ?>
						<div id="primary" <?php themeoo_main_class(); ?>>
							<main id="main" class="site-main" role="main">
		<?php
	}
endif;

if ( ! function_exists( 'themeoo_woocommerce_after_main_content' ) ) :
	/**
	 * End of the main content wrapper
	 *
	 * @return void
	 */
	function themeoo_woocommerce_after_main_content() {
		// End content wrapper.
		?>
							</main><!-- #main -->
						</div><!-- #primary -->
						<?php themeoo_try_sidebar( themeoo_get_current_screen(), 'right' ); ?>
					</div><!-- .row -->
				</div><!-- .container -->
			</div>
		</div><!-- #content -->
		<?php

	}
endif;

/**
----------------------------------------------------------------------
 * End of After and Before Main Content Hook So we can put our own layout
 * ----------------------------------------------------------------------*/

if ( ! function_exists( 'themeoo_loop_shop_per_page' ) ) {
	/**
	 * Show number of products Per Page
	 *
	 * @param int $product_number
	 *
	 * @return int
	 */
	function themeoo_loop_shop_per_page( $product_number ) {
		$per_page = (int) themeoo_get_mod( 'woocommerce_shop_archive_per_page' );
		if ( $per_page < 0 || $per_page > 0 ) {
			return $per_page;
		}

		return $product_number;
	}
}

if ( ! function_exists( 'themeoo_wc_hide_page_title' ) ) {
	/**
	 * Show Title
	 *
	 * @return bool
	 */
	function themeoo_wc_hide_page_title() {
		return themeoo_get_mod( 'woocommerce_shop_archive_title' ) == 1;
	}
}

if ( ! function_exists( 'themeoo_remove_wc_breadcrumbs' ) ) {
	/**
	 * Remove Shop Page Breadcrumbs as we have default
	 *
	 * @return void
	 */
	function themeoo_remove_wc_breadcrumbs() {
		remove_action( 'woocommerce_before_main_content', 'woocommerce_breadcrumb', 20 );
	}
}

if ( ! function_exists( 'themeoo_wc_remove_result_count' ) ) {
	/**
	 * Remove Shop Filter
	 *
	 * @return void
	 */
	function themeoo_wc_remove_result_count() {
		if ( themeoo_get_mod( 'woocommerce_shop_archive_result_count' ) == 0 ) {
			remove_action( 'woocommerce_before_shop_loop', 'woocommerce_result_count', 20 );
		} else {
			add_action( 'woocommerce_before_shop_loop', 'woocommerce_result_count', 20 );
		}
	}
}

if ( ! function_exists( 'themeoo_wc_remove_archive_short' ) ) {
	/**
	 * Remove Shop Page Filter
	 *
	 * @return void
	 */
	function themeoo_wc_remove_archive_short() {
		if ( themeoo_get_mod( 'woocommerce_shop_archive_sort' ) == 0 ) {
			remove_action( 'woocommerce_before_shop_loop', 'woocommerce_catalog_ordering', 30 );
		} else {
			add_action( 'woocommerce_before_shop_loop', 'woocommerce_catalog_ordering', 30 );
		}
	}
}

/**
----------------------------------------------------------------------
 * Function Hook For Mini Cart
 * ----------------------------------------------------------------------*/

if ( ! function_exists( 'themeoo_mini_cart' ) ) :
	/**
	 * If theme option have enable search it will show search after menu item.
	 *
	 * @param string   $items The HTML list content for the menu items.
	 * @param stdClass $args  An object containing wp_nav_menu() arguments.
	 *
	 * @return string
	 */
	function themeoo_mini_cart( $items, $args ) {
		if ( themeoo_get_mod( 'layout_header_show_mini_cart' ) && 'primary' === $args->theme_location ) {
			$items .= '<li class="header-cart-count menu-item"><a class="header-cart" href="' . wc_get_cart_url() . '"><i class="ti-shopping-cart" aria-hidden="true"></i><span class="badge">' . WC()->cart->get_cart_contents_count() . '</span></a></li>';
		}
		return $items;
	}

endif;

if ( ! function_exists( 'themeoo_iconic_cart_count_fragments' ) ) {
	/**
	 * Add item count to cart freagments.
	 *
	 * @param array $fragments
	 *
	 * @return array
	 */
	function themeoo_iconic_cart_count_fragments( $fragments ) {
		$fragments['li.header-cart-count'] = '<li class="header-cart-count menu-item"><a class="header-cart" href="' . wc_get_cart_url() . '"><i class="ti-shopping-cart" aria-hidden="true"></i><span class="badge">' . WC()->cart->get_cart_contents_count() . '</span></a></li>';
		return $fragments;

	}
}

/**
----------------------------------------------------------------------
 * Upselss Hook
 * ----------------------------------------------------------------------*/

if ( ! function_exists( 'themeoo_wc_change_number_related_products' ) ) {
	/**
	 * WC UpSell display args.
	 *
	 * @param array $args Args.
	 *
	 * @return array
	 */
	function themeoo_wc_upsell_display_args( $args ) {

		if ( is_product() ) {
			$args['posts_per_page'] = themeoo_get_mod( 'woocommerce_single_upsells_count' );
		} elseif ( is_cart() ) {
			$args['posts_per_page'] = themeoo_get_mod( 'woocommerce_cart_upsells_count' );
		} else {
			$args['posts_per_page'] = 2;
		}
		return $args;
	}
}

/**
----------------------------------------------------------------------
 * Related product
 * ----------------------------------------------------------------------*/

if ( ! function_exists( 'themeoo_wc_related_products_limit' ) ) {
	/**
	 * Related product limit.
	 *
	 * @return array
	 */
	function themeoo_wc_related_products_limit() {

		if ( is_product() ) {
			$args['posts_per_page'] = themeoo_get_mod( 'woocommerce_single_related_item_count' );
		} else {
			$args['posts_per_page'] = 4;
		}
		return $args;
	}
}

if ( ! function_exists( 'themeoo_cart_cross_sell_total' ) ) {
	/**
	 * Cross Sell Count
	 *
	 * @return int
	 */
	function themeoo_cart_cross_sell_total() {
		return absint( themeoo_get_mod( 'woocommerce_cart_cross_sell_count' ) );
	}
}

/**
----------------------------------------------------------------------
 * WooCommerce Template Override functions
 * ----------------------------------------------------------------------*/

/**
----------------------------------------------------------------------
 * STOCK
 * ----------------------------------------------------------------------*/

if ( ! function_exists( 'themeoo_stock_catalog' ) ) {
	/**
	 * Show product is in stock or out of stock.
	 *
	 * @return void
	 */
	function themeoo_stock_catalog() {
		global $product;
		if ( $product->is_in_stock() ) {
			/* translators: %s: Stock Quantity */
			echo ' <span class="stock-tag" data-bs-toggle="tooltip" data-bs-placement="bottom" title="' . sprintf( esc_attr__( 'Stock: %s', 'ayyash' ), esc_attr( $product->get_stock_quantity() ) ) . '">' . sprintf( esc_html__( '%s in stock', 'ayyash' ), esc_html( $product->get_stock_quantity() ) ) . '</span>';
		} else {
			/* translators: %s: Stock Quantity */
			echo ' <span class="stock-tag" data-bs-toggle="tooltip" data-bs-placement="bottom" title="' . sprintf( esc_attr__( 'Stock: %s', 'ayyash' ), esc_attr( $product->get_stock_quantity() ) ) . '">' . esc_html__( 'out of stock', 'ayyash' ) . '</span>';
		}
	}
}

/**
----------------------------------------------------------------------
 * New Product badge
 * ----------------------------------------------------------------------*/

if ( ! function_exists( 'themeoo_woocommerce_new_badge' ) ) {
	/**
	 * Show badge new if product is new.
	 *
	 * @return void
	 */
	function themeoo_woocommerce_new_badge() {
		global $product;
		$postdate = get_the_time( 'Y-m-d', $product->get_id() ); // Post date.
		if ( $postdate ) {
			// @phpstan-ignore-next-line
			$postdate = strtotime( $postdate ); // Timestamped post date.
			$newness  = 10;   // Newness in days as defined by option.
			if ( ( time() - ( 60 * 60 * 24 * $newness ) ) < $postdate ) { // If the product was published within the newness time frame display the new badge.
				echo '<div class="label-badge new"><span>' . esc_html__( 'New', 'ayyash' ) . '</span></div>';
			}
		}
	}
}

if ( ! function_exists( 'themeoo_sale_countdown_timer' ) ) {
	/**
	 * Sale Countdown timer
	 *
	 * @return void
	 */
	function themeoo_sale_countdown_timer() {
		global $product;

		$sale_date = $product->get_date_on_sale_to();

		if ( ! $sale_date ) {
			return;
		}

		echo '<div class="themeoo-countdown offer-time" data-date="' . esc_attr( $sale_date->date( 'Y/m/d' ) ) . '"></div>';
	}
}

if ( ! function_exists( 'themeoo_display_sold_out_loop_woocommerce' ) ) {
	/**
	 * Sold_out hook added
	 *
	 * @return void
	 */
	function themeoo_display_sold_out_loop_woocommerce() {
		global $product;

		if ( ! $product->is_in_stock() ) {
			echo '<span class="soldout">' . esc_html__( 'Out Of Stock', 'ayyash' ) . '</span>';
		}
	}
}

if ( ! function_exists( 'themeoo_filter_product_rating_html' ) ) {
	/**
	 * Filter Product rating
	 *
	 * @param string $rating_html rating html.
	 *
	 * @return string
	 */
	function themeoo_filter_product_rating_html( $rating_html ) {

		global $themeoo_products;

		if ( ! $themeoo_products ) {
			return $rating_html;
		}
		if ( isset( $themeoo_products['display_rating'] ) && 'yes' == $themeoo_products['display_rating'] ) {
			return $rating_html;
		}
		return '';
	}
}

if ( ! function_exists( 'themeoo_change_number_related_products' ) ) {
	/**
	 * Related Product Column Limit
	 *
	 * @param array $args
	 *
	 * @return array
	 */
	function themeoo_change_number_related_products( $args ) {

		$args['columns'] = absint( themeoo_get_mod( 'woocommerce_single_related_product_column' ) ); // # of columns per row
		return $args;
	}
}

if ( ! function_exists( 'themeoo_wc_gallery_thumb_size' ) ) {
	/**
	 * Product Gallery Thumb Image Size Resizing.
	 *
	 * @return array
	 */
	function themeoo_wc_gallery_thumb_size() {
		return array(
			'width'  => 300,
			'height' => 300,
			'crop'   => 0,
		);
	}
}

/**
 * Product Attribute Radio buttons
 *
 * @param string $html Data.
 * @param array  $args Arguments.
 *
 * @return string
 */
function themeoo_variation_radio_buttons( $html, $args ) {
	$args = wp_parse_args( $args, [
		'options'          => false,
		'attribute'        => false,
		'product'          => false,
		'selected'         => false,
		'name'             => '',
		'id'               => '',
		'class'            => '',
		'show_option_none' => __( 'Choose an option', 'ayyash' ),
	] );

	/**
	 * @var WC_Product_Variable $product
	 */
	$product   = $args['product'];
	$options   = $args['options'];
	$attribute = $args['attribute'];
	$name      = ! $args['name'] ? 'attribute_' . sanitize_title( $attribute ) : $args['name'];

	if ( false === $args['selected'] && $args['attribute'] && $args['product'] instanceof WC_Product ) {
		$selected_key     = 'attribute_' . sanitize_title( $args['attribute'] );
		$selected         = isset( $_REQUEST[ $selected_key ] ) ? wc_clean( wp_unslash( $_REQUEST[ $selected_key ] ) ) : ''; // phpcs:ignore WordPress.Security.NonceVerification.Recommended, WordPress.Security.ValidatedSanitizedInput.InputNotSanitized
		$args['selected'] = ! $selected ? $product->get_variation_default_attribute( $args['attribute'] ) : $selected;
	}

	if ( empty( $options ) && ! empty( $product ) && ! empty( $attribute ) ) { //@phpstan-ignore-line
		$attributes = $product->get_variation_attributes();
		$options    = $attributes[ $attribute ];
	}

	$radios = '<div class="variation-radios themeoo-attributes">';
	// Attribute label.
	$attrib_name = wc_attribute_label( $attribute, $product );

	if ( ! empty( $options ) ) {
		if ( $product && taxonomy_exists( $attribute ) ) { //@phpstan-ignore-line
			$terms = wc_get_product_terms( $product->get_id(), $attribute, [ 'fields' => 'all' ] );
			foreach ( $terms as $term ) {
				if ( in_array( $term->slug, $options, true ) ) {
					$id       = $name . '-' . $term->slug;
					$opt_name = apply_filters( 'woocommerce_variation_option_name', $term->name );
					$title    = sprintf(
					/* translators: 1. attribute label, 2. attribute value. */
						_x( '%1$s: %2$s', 'Product attribute option tooltip.', 'ayyash' ),
						$attrib_name,
						$opt_name
					);
					$output = '<span class="themeoo-attribute attribute-' . esc_attr( $name ) . '" data-bs-toggle="tooltip" data-bs-placement="bottom" title="' . esc_attr( $title ) . '" ';

					if ( 'attribute_pa_color' === $name ) {
						$color = get_term_meta( $term->term_id, 'color', true );
						$color = ! $color ? strtolower( $term->name ) : $color;

						$output .= 'style="background-color: ' . esc_attr( $color ) . '">';
						$output .= '<img alt="swatch" src="data:image/svg+xml,%3C%3Fxml%20version%3D%221.0%22%20encoding%3D%22UTF-8%22%3F%3E%0A%3Csvg%20width%3D%2218px%22%20height%3D%2213px%22%20viewBox%3D%220%200%2018%2013%22%20version%3D%221.1%22%20xmlns%3D%22http%3A%2F%2Fwww.w3.org%2F2000%2Fsvg%22%20xmlns%3Axlink%3D%22http%3A%2F%2Fwww.w3.org%2F1999%2Fxlink%22%3E%0A%20%20%20%20%3C%21--%20Generator%3A%20Sketch%2041.2%20%2835397%29%20-%20http%3A%2F%2Fwww.bohemiancoding.com%2Fsketch%20--%3E%0A%20%20%20%20%3Ctitle%3EIcon%3C%2Ftitle%3E%0A%20%20%20%20%3Cdesc%3ECreated%20with%20Sketch.%3C%2Fdesc%3E%0A%20%20%20%20%3Cdefs%3E%3C%2Fdefs%3E%0A%20%20%20%20%3Cg%20id%3D%22Page-1%22%20stroke%3D%22none%22%20stroke-width%3D%221%22%20fill%3D%22none%22%20fill-rule%3D%22evenodd%22%3E%0A%20%20%20%20%20%20%20%20%3Cg%20id%3D%22Ecommerce%22%20transform%3D%22translate%28-844.000000%2C%20-3389.000000%29%22%20fill%3D%22%23FFFFFF%22%3E%0A%20%20%20%20%20%20%20%20%20%20%20%20%3Cg%20id%3D%22Product-Card-%231%22%20transform%3D%22translate%28150.000000%2C%202942.000000%29%22%3E%0A%20%20%20%20%20%20%20%20%20%20%20%20%20%20%20%20%3Cg%20id%3D%22Color%22%20transform%3D%22translate%28683.000000%2C%20399.000000%29%22%3E%0A%20%20%20%20%20%20%20%20%20%20%20%20%20%20%20%20%20%20%20%20%3Cpath%20d%3D%22M28.8443688%2C48.9224987%20L28.095269%2C48.1585481%20C27.8879809%2C47.9471506%2027.5523969%2C47.9471506%2027.3451088%2C48.1585481%20L17.6752%2C58.0207009%20C17.4673818%2C58.2320984%2017.1317978%2C58.2320984%2016.9255701%2C58.0207009%20L12.6546937%2C53.6656962%20C12.4474056%2C53.4542987%2012.1118216%2C53.4542987%2011.9055938%2C53.6656962%20L11.1554337%2C54.4301874%20C10.9481456%2C54.6415849%2010.9481456%2C54.9838218%2011.1554337%2C55.1946786%20L16.5369712%2C60.6834443%20C16.950487%2C61.105158%2017.6211249%2C61.1056986%2018.0351709%2C60.6839849%20L28.8438387%2C49.6875305%20C29.0516569%2C49.4766737%2029.052187%2C49.1338962%2028.8443688%2C48.9224987%22%20id%3D%22Icon%22%3E%3C%2Fpath%3E%0A%20%20%20%20%20%20%20%20%20%20%20%20%20%20%20%20%3C%2Fg%3E%0A%20%20%20%20%20%20%20%20%20%20%20%20%3C%2Fg%3E%0A%20%20%20%20%20%20%20%20%3C%2Fg%3E%0A%20%20%20%20%3C%2Fg%3E%0A%3C%2Fsvg%3E" alt="' . esc_attr( $opt_name ) . '">';
					} else {
						$output .= '>' . esc_html( $term->name );
					}

					$output .= '</span>';

					$radios .= '<input type="radio" id="' . esc_attr( $id ) . '" name="' . esc_attr( $name ) . '" value="' . esc_attr( $term->slug ) . '"' . checked( sanitize_title( $args['selected'] ), $term->slug, false ) . '><label for="' . esc_attr( $id ) . '">' . $output . '</label>';
				}
			}
		} else {
			foreach ( $options as $option ) {
				$id     = $name . '-' . $option;
				$output = apply_filters( 'woocommerce_variation_option_name', $option );
				$title  = sprintf(
				/* translators: 1. attribute label, 2. attribute value. */
					_x( '%1$s: %2$s', 'Product attribute option tooltip.', 'ayyash' ),
					$attrib_name,
					$output
				);

				$output  = '<span class="themeoo-attribute attribute-' . esc_attr( $name ) . '" data-bs-toggle="tooltip" data-bs-placement="bottom" title="' . esc_attr( $title ) . '">' . esc_html( $output ) . '</span>';
				$checked = sanitize_title( $args['selected'] ) === $args['selected'] ? checked( $args['selected'], sanitize_title( $option ), false ) : checked( $args['selected'], $option, false );
				$radios .= '<input type="radio" id="' . esc_attr( $id ) . '" name="' . esc_attr( $name ) . '" value="' . esc_attr( $option ) . '"' . $checked . '><label for="' . esc_attr( $id ) . '">' . $output . '</label>';
			}
		}
	}

	$radios .= '</div>';

	return $html . $radios;
}

/**
 * Check Product Variation.
 *
 * @param bool                 $active Activate.
 * @param WC_Product_Variation $variation Variation.
 *
 * @return bool
 */
function themeoo_variation_check( $active, $variation ) {
	if ( ! $variation->is_in_stock() && ! $variation->backorders_allowed() ) {
		return false;
	}

	return $active;
}

// End of file themeoo-woocommerce-hook-helper.php
